@@ -7,7 +7,7 @@ from typing import NamedTuple, Tuple
 __all__ = ['Players']
 
 
-REGEX = compile('\\d*\. (\\w*), \\d*')
+REGEX = compile('\\d*\. ([^,]*), \\d*')
 # '\n0. azurenightwalker, 76561198056214819 \n '
 
 class Players(NamedTuple):
